@@ -13,12 +13,6 @@
 pub mod meta;
 pub use meta::*;
 
-// pub mod meta;
-// pub use meta::*;
-
-// pub use meta_tools as meta;
-// pub use meta::*;
-
 ///
 /// Type checking tools.
 ///
@@ -26,9 +20,6 @@ pub use meta::*;
 pub mod typing;
 pub use typing::*;
 
-// pub use typing_tools as typing;
-// pub use typing::*;
-
 ///
 /// Exporting/importing serialize/deserialize encoding/decoding macros, algorithms and structures for that.
 ///
@@ -36,11 +27,6 @@ pub use typing::*;
 pub mod convert;
 pub use convert::*;
 
-// pub mod typing;
-// pub use inspect_type::*;
-// pub use is_slice::*;
-// pub use implements::*;
-
 ///
 /// Collection of general purpose time tools.
 ///
@@ -49,11 +35,15 @@ pub mod time;
 
 //
 
-pub use former as former;
 pub use werror as error;
 
-#[ cfg( feature = "with_proc_macro" ) ]
-pub use wproc_macro as proc_macro;
+// #[ cfg( feature = "with_proc_macro" ) ]
+// pub use proc_macro_tools as proc_macro;
+
+pub use former as former;
+pub use woptions as options;
+pub use winterval as interval;
+pub use wstring_tools as string;
 
 ///
 /// Prelude to use: `use wtools::prelude::*`.
@@ -63,3 +53,25 @@ pub mod prelude
 {
   pub use super::*;
 }
+
+///
+/// Dependencies.
+///
+
+pub mod dependencies
+{
+
+  pub use ::former;
+  pub use ::woptions;
+  pub use ::meta_tools;
+  pub use ::typing_tools;
+  pub use ::time_tools;
+  pub use ::wstring_tools;
+  pub use ::werror;
+  pub use ::winterval;
+  pub use ::parse_display; /* xxx : move to stringing */
+
+  // #[ cfg( debug_assertions ) ]
+  // pub use ::wtest_basic;
+
+}
